@@ -1,15 +1,18 @@
 import logging
+from contextlib import asynccontextmanager, suppress
 
 import redis_lock
 
-from rediskit import config, redis_client
+from rediskit import config
+from rediskit.redis.a_client import get_async_redis_connection
+from rediskit.redis.client import get_redis_connection
 
 log = logging.getLogger(__name__)
 
 
 def get_redis_mutex_lock(lock_name: str, expire: int = 30, auto_renewal: bool = True, id: str | None = None) -> redis_lock.Lock:
     return redis_lock.Lock(
-        redis_client.get_redis_connection(),
+        get_redis_connection(),
         name=f"{config.REDIS_KIT_LOCK_SETTINGS_REDIS_NAMESPACE}:{lock_name}",
         id=id,
         expire=expire,
@@ -27,7 +30,7 @@ def get_async_redis_mutex_lock(
     thread_local: bool = True,
     raise_on_release_error: bool = True,
 ) -> redis_lock.Lock:
-    conn = redis_client.get_async_redis_connection()
+    conn = get_async_redis_connection()
     lock = conn.lock(
         f"{config.REDIS_KIT_LOCK_ASYNC_SETTINGS_REDIS_NAMESPACE}:{lock_name}",
         timeout=expire,  # lock TTL
@@ -39,3 +42,18 @@ def get_async_redis_mutex_lock(
         raise_on_release_error=raise_on_release_error,  # avoid exception if expired
     )
     return lock
+
+
+@asynccontextmanager
+async def nonblocking_mutex(name: str, **lock_kwargs):
+    lock = get_async_redis_mutex_lock(name, **lock_kwargs)
+    acquired = await lock.acquire(blocking=False)
+    if not acquired:
+        yield False
+        return
+
+    try:
+        yield True
+    finally:
+        with suppress(Exception, getattr(redis_lock, "NotAcquired", Exception)):
+            await lock.release()
